==> com.liferay.account.admin.web-1.0.21-sources.jar: META-INF/resources/account_entries_admin/js/AccountEntriesAdminPortlet.es.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

import {PortletBase} from 'frontend-js-web';
import dom from 'metal-dom';
import {EventHandler} from 'metal-events';

class AccountEntriesAdminPortlet extends PortletBase {

	/**
	 * @inheritDoc
	 */
	created() {
		this.eventHandler_ = new EventHandler();
	}

	/**
	 * @inheritDoc
	 */
	attached() {
		this.businessAccountOnlySection = this.one('.business-account-only');

		const typeSelect = this.one('#type');

		if (typeSelect) {
			this.updateVisibility_(typeSelect);

			this.eventHandler_.add(
				dom.on(typeSelect, 'change', (e) => {
					this.updateVisibility_(e.currentTarget);
				})
			);
		}
	}

	/**
	 * Hides or shows the business-account-only fields in the edit form.
	 *
	 * @param {HTMLSelectElement} typeSelect
	 * @private
	 */
	updateVisibility_(typeSelect) {
		if (typeSelect.value === 'business') {
			dom.removeClasses(this.businessAccountOnlySection, 'hide');
		}
		else {
			dom.addClasses(this.businessAccountOnlySection, 'hide');
		}
	}

	/**
	 * @inheritDoc
	 */
	detached() {
		super.detached();
		this.eventHandler_.removeAllListeners();
	}
}

export default AccountEntriesAdminPortlet;

==> com.liferay.account.admin.web-2.0.21-sources.jar: META-INF/resources/account_entries_admin/js/AccountEntriesAdminPortlet.es.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

import {PortletBase} from 'frontend-js-web';

class AccountEntriesAdminPortlet extends PortletBase {

	/**
	 * @inheritDoc
	 */
	created() {
		this._handleTypeSelectChange = this._handleTypeSelectChange.bind(this);
	}

	/**
	 * @inheritDoc
	 */
	attached() {
		const typeSelect = this.one('#type');

		if (typeSelect) {
			this._updateVisibility(typeSelect);

			typeSelect.addEventListener('change', this._handleTypeSelectChange);
		}
	}

	_handleTypeSelectChange(event) {
		this._updateVisibility(event.currentTarget);
	}

	/**
	 * Hides or shows the business-account-only fields in the edit form.
	 *
	 * @param {HTMLSelectElement} typeSelect
	 * @private
	 */
	_updateVisibility(typeSelect) {
		const businessAccountOnlySection = this.one('.business-account-only');

		if (businessAccountOnlySection) {
			businessAccountOnlySection.classList.toggle(
				'hide',
				typeSelect.value === 'person'
			);
		}
	}

	/**
	 * @inheritDoc
	 */
	detached() {
		super.detached();

		const typeSelect = this.one('#type');

		if (typeSelect) {
			typeSelect.removeEventListener(
				'change',
				this._handleTypeSelectChange
			);
		}
	}
}

export default AccountEntriesAdminPortlet;
